@@ -41,9 +41,7 @@ import urllib
 
 module_path = os.path.abspath(os.path.dirname(__file__))
 
-MOZILLA_PLUGINS = [os.path.join(module_path, 'extension'),
-                   # os.path.join(module_path, 'xpi', 'mozlab-current-0.1.9.2008050521.xpi'),
-                   ]
+MOZILLA_PLUGINS = []
 
 basedir = os.path.abspath(os.path.dirname(__file__))
 
@@ -55,7 +53,7 @@ MOZILLA_PREFERENCES = {
     'extensions.venkman.enableChromeFilter' : False,
     }
 
-MOZILLA_CMD_ARGS = ['-jsbridge', '24242', ]
+MOZILLA_CMD_ARGS = []
 
 MOZILLA_CREATE_NEW_PROFILE = True
 
