@@ -41,9 +41,12 @@ import logging
 import uuid
 from time import sleep
 
-import simplejson
+try:
+    import json as simplejson
+except:
+    import simplejson
 
-import callbacks
+import events
 
 logger = logging.getLogger(__name__)
 
@@ -61,11 +64,8 @@ class Telnet(object, asyncore.dispatcher):
     def __del__(self):
         self.close()
 
-    def handle_connect(self):
-        self.logger.debug('Connected '+self.host+' on port '+str(self.port))
-        
     def handle_close(self):
-        self.logger.debug('Closed '+self.host+' on port '+str(self.port))
+        self.close()
 
     def handle_expt(self): self.close() # connection failed, shutdown
     
@@ -77,7 +77,6 @@ class Telnet(object, asyncore.dispatcher):
         self.buffer = self.buffer[sent:]
         
     def send(self, b):
-        #print b
         asyncore.dispatcher.send(self, b)
 
     def read_all(self):
@@ -91,14 +90,16 @@ class Telnet(object, asyncore.dispatcher):
 
     def handle_read(self):
         self.data = self.read_all()
-        logger.debug('Raw RECV::'+self.data)
         self.process_read(self.data)
         
     read_callback = lambda self, data: None
 
 decoder = simplejson.JSONDecoder()
 
-from simplejson.encoder import encode_basestring_ascii, encode_basestring, floatstr 
+try:
+    from json.encoder import encode_basestring_ascii, encode_basestring
+except:
+    from simplejson.encoder import encode_basestring_ascii, encode_basestring
 
 class JSObjectEncoder(simplejson.JSONEncoder):
     """Encoder that supports jsobject references by name."""
@@ -126,7 +127,7 @@ class JSObjectEncoder(simplejson.JSONEncoder):
         elif isinstance(o, (int, long)):
             yield str(o)
         elif isinstance(o, float):
-            yield floatstr(o, self.allow_nan)
+            yield getattr(simplejson.encoder, 'floatstr', simplejson.encoder._floatstr)(o, self.allow_nan)
         elif isinstance(o, (list, tuple)):
             for chunk in self._iterencode_list(o, markers):
                 yield chunk
@@ -154,9 +155,12 @@ class Bridge(Telnet):
     events_list = []
 
     callbacks = {}
-
+    
+    bridge_type = "bridge"
+    
     def __init__(self, *args, **kwargs):
         Telnet.__init__(self, *args, **kwargs)  
+        self.connect(args)
     
     def handle_connect(self):
         self.register()
@@ -175,7 +179,7 @@ class Bridge(Telnet):
         
     def register(self):
         _uuid = str(uuid.uuid1())
-        self.send('bridge.register("'+_uuid+'", "bridge")\r\n')
+        self.send('bridge.register("'+_uuid+'", "'+self.bridge_type+'")\r\n')
 
     def execFunction(self, func_name, args, interval=.25):
         _uuid = str(uuid.uuid1())
@@ -219,22 +223,24 @@ class Bridge(Telnet):
                 self.sbuffer = self.sbuffer[index:]
         
 class BridgeBackChannel(Bridge):
+    
+    bridge_type = "backchannel"
         
     def fire_callbacks(self, obj):
         """Handle all callback fireing on json objects pulled from the data stream."""
-        callbacks.fire_event(**dict([(str(key), value,) for key, value in obj.items()]))
-        
-    def register(self):
-        _uuid = str(uuid.uuid1())
-        self.send('bridge.register("'+_uuid+'", "backchannel")\r\n')
+        events.fire_event(**dict([(str(key), value,) for key, value in obj.items()]))
+
 
 def create_network(hostname, port):
+    
     global back_channel, bridge
     back_channel = BridgeBackChannel(hostname, port)
     bridge = Bridge(hostname, port)
+    
     from threading import Thread
     global thread
     thread = Thread(target=asyncore.loop)
     getattr(thread, 'setDaemon', lambda x : None)(True)
     thread.start()
+    
     return back_channel, bridge
